GtkIconView.view.cell:selected,
GtkIconView.view.cell:selected:focused {
    background-color: alpha(@theme_base_color, 0.0);

    border-style: solid;
    border-radius: 10;
    border-width: 3;
    border-color: #d3d7cf;

    /* FIXME: this probably needs to be better;
     * see https://bugzilla.gnome.org/show_bug.cgi?id=644157
     */
    -adwaita-focus-border-color: alpha(@theme_text_color, 0.4);
    -adwaita-focus-border-radius: 5;
    -adwaita-focus-border-dashes: true;
}

.entry:insensitive {
    background-image: none;
}